@@ -23,11 +23,11 @@ Email::ExactTarget::SubscriberOperations
 
 =head1 VERSION
 
-Version 1.3.5
+Version 1.3.6
 
 =cut
 
-our $VERSION = '1.3.5';
+our $VERSION = '1.3.6';
 
 
 =head1 SYNOPSIS
@@ -195,7 +195,7 @@ sub update
 Retrieves from ExactTarget's database the subscribers corresponding to the
 unique identifiers passed as parameter.
 
-	my @subscriber = $subscriber_operations->retrieve(
+	my $subscribers = $subscriber_operations->retrieve(
 		'email' => [ $email1, $email2 ],
 	);
 
@@ -901,10 +901,16 @@ and write code for them!
 
 Copyright 2009-2012 Guillaume Aubert.
 
-This program is free software; you can redistribute it and/or modify it
-under the terms of the Artistic License.
+This program is free software: you can redistribute it and/or modify it under
+the terms of the GNU General Public License version 3 as published by the Free
+Software Foundation.
 
-See http://dev.perl.org/licenses/ for more information.
+This program is distributed in the hope that it will be useful, but WITHOUT ANY
+WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+PARTICULAR PURPOSE. See the GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License along with
+this program. If not, see http://www.gnu.org/licenses/
 
 =cut
 
